Using CUDA Function Load and C compiler error Red Hat RHEL 6.5

I am using CUDA under Red Hat Linux RHEL 6.5 86_64 . ; I am using the NVIDIA driver and a GeoForce 630 Card.

entered this code

doubleFun = CUDAFunctionLoad["
  __global__ void doubleVec(mint * in,  mint length) {
      mint index = threadIdx.x + blockIdx.x * blockDim.x;
  
   if (index < length)
     in[index] = 2*in[index];
    }", "doubleVec", {{_Integer}, _Integer}, 256, 
  ShellOutputFunction -> Print]

Then I got the followng error

CUDAFunctionLoad::cmpf: The kernel compilation failed. Consider setting the option “ShellOutputFunction”->Print to display the compiler error message. >>

The shelloutPrint options returns the following eror
gcc: error trying to exec ‘cc1plus’: execvp: No such file or directory

Need your help. I code was extracted from Wolfram CUDALink documentation. As you may see, confusing because the cc1plus:execvp is not part of my writen code.